@@ -58,22 +58,12 @@ QHash<int, QByteArray> EventModel::roleNames() const
             {ShiftedEventDt, "shiftedEventDt"},
             {ShiftedEventDtLocal, "shiftedEventDtLocal"},
             {ScheduleStartDt, "scheduleStartDt"},
-            {AllDay, "allday"},
             {Description, "description"},
             {Summary, "summary"},
-            {LastModified, "lastmodified"},
             {Location, "location"},
             {Categories, "categories"},
-            {Priority, "priority"},
-            {Created, "created"},
-            {Secrecy, "secrecy"},
             {EventEndDt, "eventEndDt"},
             {ScheduleEndDt, "scheduleEndDt"},
-            {Transparency, "transparency"},
-            {RepeatPeriodType, "repeatType"},
-            {RepeatEvery, "repeatEvery"},
-            {RepeatStopAfter, "repeatStopAfter"},
-            {IsRepeating, "isRepeating"},
             {EventCategories, "eventCategories"},
             {Url, "url"},
             {ShiftedStartEndDt, "shiftedStartEndDt"},
@@ -126,40 +116,20 @@ QVariant EventModel::data(const QModelIndex &index, int role) const
         applyTimeZone(startDtTime, calendarTz);
         return startDtTime;
     }
-    case AllDay:
-        return allDay;
     case Description:
         return m_events.at(row)->description();
     case Summary:
         return m_events.at(row)->summary();
-    case LastModified:
-        return m_events.at(row)->lastModified();
     case Location:
         return m_events.at(row)->location();
     case Categories:
         return m_events.at(row)->categories();
-    case Priority:
-        return m_events.at(row)->priority();
-    case Created:
-        return m_events.at(row)->created();
-    case Secrecy:
-        return m_events.at(row)->secrecy();
     case EventEndDt:
         return endDtTime;
     case ScheduleEndDt: {
         applyTimeZone(endDtTime, calendarTz);
         return endDtTime;
     }
-    case Transparency:
-        return m_events.at(row)->transparency();
-    case RepeatPeriodType:
-        return repeatPeriodType(row);
-    case RepeatEvery:
-        return repeatEvery(row);
-    case RepeatStopAfter:
-        return repeatStopAfter(row);
-    case IsRepeating:
-        return m_events.at(row)->recurs();
     case EventCategories:
         return m_events.at(row)->categoriesStr();
     case Url:
@@ -253,33 +223,6 @@ void EventModel::loadEvents()
     endResetModel();
 }
 
-int EventModel::repeatEvery(const int idx) const
-{
-    if (!(m_events.at(idx)->recurs())) {
-        return 0;
-    }
-
-    return m_events.at(idx)->recurrence()->frequency();
-}
-
-int EventModel::repeatStopAfter(const int idx) const
-{
-    if (!(m_events.at(idx)->recurs())) {
-        return -1;
-    }
-
-    return m_events.at(idx)->recurrence()->duration();
-}
-
-ushort EventModel::repeatPeriodType(const int idx) const
-{
-    if (!(m_events.at(idx)->recurs())) {
-        return KCalendarCore::Recurrence::rNone;
-    }
-
-    return m_events.at(idx)->recurrence()->recurrenceType();
-}
-
 void EventModel::setEventCategory(const QString &category)
 {
     if (m_category != category) {
@@ -309,11 +252,11 @@ int EventModel::overlappingEvents(const int idx) const
 QString EventModel::formatStartEndTime(const QDateTime &startDtTime, const QDateTime &endDtTime) const
 {
     if (startDtTime.date() == endDtTime.date()) {
-        return "%1 - %2"_L1.arg(startDtTime.time().toString(u"hh:mm"), endDtTime.time().toString(u"hh:mm"));
+        return "%1 - %2"_L1.arg(QLocale().toString(startDtTime.time(), QLocale::ShortFormat), QLocale().toString(endDtTime.time(), QLocale::ShortFormat));
     }
 
-    auto displayStartDtTime = "%1 %2"_L1.arg(startDtTime.date().toString(u"ddd d MMM yyyy"), startDtTime.time().toString(u"hh:mm"));
-    auto displayEndDtTime = "%1 %2"_L1.arg(endDtTime.date().toString(u"ddd d MMM yyyy"), endDtTime.time().toString(u"hh:mm"));
+    auto displayStartDtTime = "%1 %2"_L1.arg(startDtTime.date().toString(u"ddd d MMM yyyy"), QLocale().toString(startDtTime.time(), QLocale::ShortFormat));
+    auto displayEndDtTime = "%1 %2"_L1.arg(endDtTime.date().toString(u"ddd d MMM yyyy"), QLocale().toString(endDtTime.time(), QLocale::ShortFormat));
 
     return "%1 - %2 %3"_L1.arg(displayStartDtTime, displayEndDtTime, startDtTime.timeZoneAbbreviation());
 }
@@ -326,13 +269,14 @@ QString EventModel::formatStartEndDt(const QDateTime &startDtTime, const QDateTi
 
     if (startDtTime.date() == endDtTime.date()) {
         auto displayDt = startDtTime.date().toString(u"ddd d MMM yyyy");
-        auto displayTime = "%1 - %2"_L1.arg(startDtTime.time().toString(u"hh:mm"), endDtTime.time().toString(u"hh:mm"));
+        auto displayTime =
+            "%1 - %2"_L1.arg(QLocale().toString(startDtTime.time(), QLocale::ShortFormat), QLocale().toString(endDtTime.time(), QLocale::ShortFormat));
 
         return "%1 %2 %3"_L1.arg(displayDt, displayTime, startDtTime.timeZoneAbbreviation());
     }
 
-    auto displayStartDtTime = "%1 %2"_L1.arg(startDtTime.date().toString(u"ddd d MMM yyyy"), startDtTime.time().toString(u"hh:mm"));
-    auto displayEndDtTime = "%1 %2"_L1.arg(endDtTime.date().toString(u"ddd d MMM yyyy"), endDtTime.time().toString(u"hh:mm"));
+    auto displayStartDtTime = "%1 %2"_L1.arg(startDtTime.date().toString(u"ddd d MMM yyyy"), QLocale().toString(startDtTime.time(), QLocale::ShortFormat));
+    auto displayEndDtTime = "%1 %2"_L1.arg(endDtTime.date().toString(u"ddd d MMM yyyy"), QLocale().toString(endDtTime.time(), QLocale::ShortFormat));
 
     return "%1 - %2 %3"_L1.arg(displayStartDtTime, displayEndDtTime, startDtTime.timeZoneAbbreviation());
 }
